@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -33,8 +33,8 @@ import javax.ejb.RemoveException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.JobConstant;
 import com.clustercontrol.commons.util.ConnectionManager;
+import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean;
 import com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK;
 
@@ -48,40 +48,42 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO
  */
 public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobCommandInfoDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobCommandInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
 	 */
+	@Override
 	public void load(JobCommandInfoPK pk, JobCommandInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_command_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setArgument(res.getString("argument"));
@@ -96,7 +98,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 				ejb.setStart_command(res.getString("start_command"));
 				ejb.setStop_command(res.getString("stop_command"));
 				ejb.setJobunit_id(res.getString("jobunit_id"));
-				
+
 			} else {
 				String msg = "JobCommandInfo data is not found.";
 				m_log.error("load() error : " + pk.toString() + " SQLException " + msg);
@@ -124,21 +126,22 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * UPDATE文を発行します。
 	 * 引数で指定されたEntity Beanの内容でデータベースを更新します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
 	 */
+	@Override
 	public void store(JobCommandInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
 				+ ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
@@ -156,10 +159,10 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			sql.append("WHERE session_id = ? AND ");
 			sql.append("job_id = ? AND ");
 			sql.append("jobunitId = ?");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getFacility_id());
 			stmt.setInt(2, ejb.getProcess_mode());
 			stmt.setString(3, ejb.getStart_command());
@@ -172,9 +175,9 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			stmt.setString(10, ejb.getSession_id());
 			stmt.setString(11, ejb.getJob_id());
 			stmt.setString(12, ejb.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("store() error : sessionId=" + ejb.getSession_id()
@@ -184,8 +187,8 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			}
 		} catch (SQLException e) {
 			m_log.error("store() error : sessionId=" + ejb.getSession_id()
-						+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
-						+ ejb.getJob_id() + " SQLException");
+					+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
+					+ ejb.getJob_id() + " SQLException");
 			throw new EJBException(e.getMessage());
 		} finally {
 			// コネクション、結果セット、プリペアドステートメントのクローズ
@@ -204,44 +207,45 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			}
 		}
 		m_log.debug("store() end : sessionId=" + ejb.getSession_id()
-						+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
-						+ ejb.getJob_id());
+				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
+				+ ejb.getJob_id());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK)
 	 */
+	@Override
 	public void remove(JobCommandInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_command_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -257,18 +261,19 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean)
 	 */
+	@Override
 	public JobCommandInfoPK create(JobCommandInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
 				+ ejb.getJob_id());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobCommandInfoPK pk;
@@ -290,10 +295,10 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			sql.append("argument, ");
 			sql.append("jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setString(3, ejb.getFacility_id());
@@ -306,25 +311,25 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			stmt.setString(10, ejb.getArgument_job_id());
 			stmt.setString(11, ejb.getArgument());
 			stmt.setString(12, ejb.getJobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobCommandInfoPK(
 					ejb.getSession_id(),
 					ejb.getJobunit_id(),
 					ejb.getJob_id());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
-				+ ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
+						+ ejb.getJob_id() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
-				+ ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
+						+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
+						+ ejb.getJob_id() + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -338,8 +343,8 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
-				+ ejb.getJob_id() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id() + ", jobId="
+						+ ejb.getJob_id() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -348,7 +353,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 				+ ejb.getJob_id());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -356,22 +361,23 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobCommandInfoPK> ret = new ArrayList<JobCommandInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_command_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobCommandInfoPK pk= new JobCommandInfoPK(
 						res.getString("session_id"),
@@ -380,7 +386,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -401,7 +407,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -409,26 +415,27 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoPK)
 	 */
+	@Override
 	public JobCommandInfoPK findByPrimaryKey(JobCommandInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_command_info WHERE session_id = ? AND job_id = ? AND jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getJobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -454,7 +461,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定されたファシリティIDで、データベースを検索します。
@@ -462,25 +469,26 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobCommandInfoBean#ejbFindByFacilityId(String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobCommandInfoDAO#findByFacilityId(java.lang.String)
 	 */
+	@Override
 	public Collection findByFacilityId(String facilityId) throws FinderException {
 		m_log.debug("findByFacilityId() start : " + facilityId);
-		
+
 		ArrayList<JobCommandInfoPK> ret = new ArrayList<JobCommandInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id FROM cc_job_command_info WHERE facility_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, facilityId);
-			
+
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobCommandInfoPK pk= new JobCommandInfoPK(
 						res.getString("session_id"),
@@ -489,7 +497,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findByFacilityId() error : " + facilityId + " SQLException");
 			throw new EJBException(e.getMessage());
@@ -510,7 +518,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 		m_log.debug("findByFacilityId() end : " + facilityId);
 		return ret;
 	}
-	
+
 	/**
 	 * ジョブコマンド情報をジョブコマンドマスタから作成します。
 	 * 
@@ -522,17 +530,17 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 	 */
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
-		Connection conn = null; 
+
+		Connection conn = null;
 		Connection connMaster = null;
 		PreparedStatement stmt = null;
 		PreparedStatement stmtMaster = null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_command_info (");
@@ -554,7 +562,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1,sessionId);
 			stmt.setString(12, jobunitId);
-			
+
 			//SQL文の定義(マスタ検索)
 			StringBuilder sqlMaster = new StringBuilder();
 			sqlMaster.append("SELECT ");
@@ -576,23 +584,23 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 			sqlMaster.append("AND cc_job_mst.job_id = ? ");
 			sqlMaster.append("AND cc_job_mst.jobunit_id = ? ");
 			sqlMaster.append(")");
-			
+
 			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL実行(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				if (resMaster.next()) {
 					if(resMaster.getInt("job_type") == JobConstant.TYPE_JOB){
 						//ジョブの場合、INSERTを実行
@@ -606,7 +614,7 @@ public class JobCommandInfoDAOImpl implements JobCommandInfoDAO {
 						stmt.setInt(9, resMaster.getInt("error_end_value"));
 						stmt.setString(10, resMaster.getString("argument_job_id"));
 						stmt.setString(11, resMaster.getString("argument"));
-						
+
 						int row =	stmt.executeUpdate();
 						if (row != 1) {
 							String msg = "result row is not 1";
