@@ -1,16 +1,16 @@
 /*
- 
+
  Copyright (C) 2006 NTT DATA Corporation
- 
+
  This program is free software; you can redistribute it and/or
- Modify it under the terms of the GNU General Public License 
+ Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be
- useful, but WITHOUT ANY WARRANTY; without even the implied 
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ useful, but WITHOUT ANY WARRANTY; without even the implied
+ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.jobmanagement.dao;
@@ -47,34 +47,36 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoPK;
  * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO
  */
 public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
-	
+
 	/** ログ出力のインスタンス。 */
-	protected static Log m_log = LogFactory.getLog(JobStartJobInfoDAOImpl.class);
-	
+	private static Log m_log = LogFactory.getLog(JobStartJobInfoDAOImpl.class);
+
+	@Override
 	public void init() {
 	}
-	
-	/** 
+
+	/**
 	 * SELECT文を発行します。
 	 * 引数で指定されたプライマリキーで検索し、取得したデータベースの内容をEntity Beanに反映します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#load(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoPK, com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean)
 	 */
+	@Override
 	public void load(JobStartJobInfoPK pk, JobStartJobInfoBean ejb) throws EJBException {
 		m_log.debug("load() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT * FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ? AND target_job_id = ? AND target_job_type = ? AND target_job_end_value = ? AND jobunit_id = ? AND target_jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getTarget_job_id());
@@ -82,9 +84,9 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			stmt.setInt(5, pk.getTarget_job_end_value());
 			stmt.setString(6, pk.getJobunit_id());
 			stmt.setString(7, pk.getTarget_jobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				//取得した値をBeanにセット
 				ejb.setJobunit_id(res.getString("jobunit_id"));
@@ -121,13 +123,14 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		}
 		m_log.debug("load() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * データベースの更新を行うのが基本だが、<BR>
 	 * 全てのカラムが主キーになっているので、更新を行う必要はない。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#store(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean)
 	 */
+	@Override
 	public void store(JobStartJobInfoBean ejb) throws EJBException {
 		m_log.debug("store() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
@@ -142,26 +145,27 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 				+ ejb.getTarget_job_type() + ", "
 				+ ejb.getTarget_job_end_value());
 	}
-	
+
 	/**
 	 * DELETE文を発行します。
 	 * 引数で指定されたプライマリキーでデータベースから削除します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#remove(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoPK)
 	 */
+	@Override
 	public void remove(JobStartJobInfoPK pk) throws RemoveException, EJBException {
 		m_log.debug("remove() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "DELETE FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ? AND target_job_id = ? AND target_job_type = ? AND target_job_end_value = ? AND jobunit_id = ? AND target_jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getTarget_job_id());
@@ -169,18 +173,18 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			stmt.setInt(5, pk.getTarget_job_end_value());
 			stmt.setString(6, pk.getJobunit_id());
 			stmt.setString(7, pk.getTarget_jobunit_id());
-			
+
 			int row = stmt.executeUpdate();
-			
+
 			if (row != 1 ) {
 				String msg = "result row is not 1";
 				m_log.error("remove() error : " + pk.toString() + " SQLException" + msg);
-				throw new EJBException(msg);	
+				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			m_log.error("remove() error : " + pk.toString() + " SQLException");
 			throw new EJBException(e.getMessage());
-			
+
 		} finally {
 			try {
 				if(stmt != null){
@@ -196,13 +200,14 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		}
 		m_log.debug("remove() end : " + pk.toString());
 	}
-	
+
 	/**
 	 * INSERT文を発行します。
 	 * 引数で指定されたEntity Beanの内容をデータベースに挿入し、プライマリキーを返します。
 	 * 
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#create(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean)
 	 */
+	@Override
 	public JobStartJobInfoPK create(JobStartJobInfoBean ejb) throws CreateException, EJBException {
 		m_log.debug("create() start : sessionId=" + ejb.getSession_id()
 				+ ", jobunitId=" + ejb.getJobunit_id()
@@ -211,7 +216,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 				+ ", targetJobId=" + ejb.getTarget_job_id()
 				+ ", targetJobType=" + ejb.getTarget_job_type()
 				+ ", targetJobEndValue=" + ejb.getTarget_job_end_value());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		JobStartJobInfoPK pk;
@@ -228,10 +233,10 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			sql.append("jobunit_id, ");
 			sql.append("target_jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql.toString());
-			
+
 			stmt.setString(1, ejb.getSession_id());
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setString(3, ejb.getTarget_job_id());
@@ -239,7 +244,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			stmt.setInt(5, ejb.getTarget_job_end_value());
 			stmt.setString(6, ejb.getJobunit_id());
 			stmt.setString(7, ejb.getTarget_jobunit_id());
-			
+
 			int row =	stmt.executeUpdate();
 			pk = new JobStartJobInfoPK(
 					ejb.getSession_id(),
@@ -247,29 +252,29 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 					ejb.getJob_id(),
 					ejb.getTarget_jobunit_id(),
 					ejb.getTarget_job_id(),
-					ejb.getTarget_job_type(), 
+					ejb.getTarget_job_type(),
 					ejb.getTarget_job_end_value());
-			
+
 			if (row != 1) {
 				String msg = "result row is not 1";
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id()
-				+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
-				+ ", targetJobId=" + ejb.getTarget_job_id()
-				+ ", targetJobType=" + ejb.getTarget_job_type()
-				+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id()
+						+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
+						+ ", targetJobId=" + ejb.getTarget_job_id()
+						+ ", targetJobType=" + ejb.getTarget_job_type()
+						+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException");
 				throw new EJBException(msg);
 			}
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id()
-				+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
-				+ ", targetJobId=" + ejb.getTarget_job_id()
-				+ ", targetJobType=" + ejb.getTarget_job_type()
-				+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException"
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id()
+						+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
+						+ ", targetJobId=" + ejb.getTarget_job_id()
+						+ ", targetJobType=" + ejb.getTarget_job_type()
+						+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException"
 						+ "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
@@ -284,12 +289,12 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("create() error : sessionId=" + ejb.getSession_id()
-				+ ", jobunitId=" + ejb.getJobunit_id()
-				+ ", jobId=" + ejb.getJob_id()
-				+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
-				+ ", targetJobId=" + ejb.getTarget_job_id()
-				+ ", targetJobType=" + ejb.getTarget_job_type()
-				+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException");
+						+ ", jobunitId=" + ejb.getJobunit_id()
+						+ ", jobId=" + ejb.getJob_id()
+						+ ", targetJobunitId=" + ejb.getTarget_jobunit_id()
+						+ ", targetJobId=" + ejb.getTarget_job_id()
+						+ ", targetJobType=" + ejb.getTarget_job_type()
+						+ ", targetJobEndValue=" + ejb.getTarget_job_end_value() + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
@@ -302,7 +307,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 				+ ", targetJobEndValue=" + ejb.getTarget_job_end_value());
 		return pk;
 	}
-	
+
 	/**
 	 * 全件取得するSELECT文を発行します。
 	 * 取得したデータのプライマリキーをコレクションに格納し返します。
@@ -310,22 +315,23 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean#ejbFindAll()
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#findAll()
 	 */
+	@Override
 	public Collection findAll() throws FinderException {
 		m_log.debug("findAll() start : ");
-		
+
 		ArrayList<JobStartJobInfoPK> ret = new ArrayList<JobStartJobInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id, target_jobunit_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobStartJobInfoPK pk= new JobStartJobInfoPK(
 						res.getString("session_id"),
@@ -333,12 +339,12 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 						res.getString("job_id"),
 						res.getString("target_jobunit_id"),
 						res.getString("target_job_id"),
-						res.getInt("target_job_type"), 
+						res.getInt("target_job_type"),
 						res.getInt("target_job_end_value")
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findAll() error :  SQLException");
 			throw new EJBException(e.getMessage());
@@ -359,7 +365,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		m_log.debug("findAll() end : ");
 		return ret;
 	}
-	
+
 	/**
 	 * 1件取得するSELECT文を発行します。
 	 * 引数で指定されたプライマリキーで、データベースを検索します。
@@ -367,20 +373,21 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean#ejbFindByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoPK)
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#findByPrimaryKey(com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoPK)
 	 */
+	@Override
 	public JobStartJobInfoPK findByPrimaryKey(JobStartJobInfoPK pk) throws FinderException {
 		m_log.debug("findByPrimaryKey() start : " + pk.toString());
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id, target_jobunit_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ? AND target_job_id = ? AND target_job_type = ? AND target_job_end_value = ? AND jobunit_id = ? AND target_jobunit_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, pk.getSession_id());
 			stmt.setString(2, pk.getJob_id());
 			stmt.setString(3, pk.getTarget_job_id());
@@ -388,9 +395,9 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			stmt.setInt(5, pk.getTarget_job_end_value());
 			stmt.setString(6, pk.getJobunit_id());
 			stmt.setString(7, pk.getTarget_jobunit_id());
-			
+
 			res = stmt.executeQuery();
-			
+
 			if (res.next()) {
 				return pk;
 			} else {
@@ -416,7 +423,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			m_log.debug("findByPrimaryKey() end : " + pk.toString());
 		}
 	}
-	
+
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定されたセッションIDと待ち条件対象ジョブIDで、データベースを検索します。
@@ -424,26 +431,27 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean#ejbFindByTargetJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#findByTargetJobId(java.lang.String, java.lang.String)
 	 */
+	@Override
 	public Collection findByTargetJobId(String session_id, String target_job_id) throws FinderException {
 		m_log.debug("findByTargetJobId() start : " + session_id + ", " + target_job_id);
-		
+
 		ArrayList<JobStartJobInfoPK> ret = new ArrayList<JobStartJobInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id, target_jobunit_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND target_job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, session_id);
 			stmt.setString(2, target_job_id);
-			
+
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobStartJobInfoPK pk= new JobStartJobInfoPK(
 						res.getString("session_id"),
@@ -451,12 +459,12 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 						res.getString("job_id"),
 						res.getString("target_jobunit_id"),
 						res.getString("target_job_id"),
-						res.getInt("target_job_type"), 
+						res.getInt("target_job_type"),
 						res.getInt("target_job_end_value")
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findByTargetJobId() error : " + session_id + ", " + target_job_id + " SQLException");
 			throw new EJBException(e.getMessage());
@@ -477,7 +485,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		m_log.debug("findByTargetJobId() end : " + session_id + ", " + target_job_id);
 		return ret;
 	}
-	
+
 	/**
 	 * 複数件取得するSELECT文を発行します。
 	 * 引数で指定されたセッションIDとジョブIDで、データベースを検索します。
@@ -485,26 +493,27 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobStartJobInfoBean#ejbFindBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 * @see com.clustercontrol.jobmanagement.dao.JobStartJobInfoDAO#findBySessionIdAndJobId(java.lang.String, java.lang.String)
 	 */
+	@Override
 	public Collection findBySessionIdAndJobId(String session_id, String job_id) throws FinderException {
 		m_log.debug("findBySessionIdAndJobId() start : " + session_id + ", " + job_id);
-		
+
 		ArrayList<JobStartJobInfoPK> ret = new ArrayList<JobStartJobInfoPK>();
-		
+
 		Connection conn = null;
 		PreparedStatement stmt = null;
 		ResultSet res = null;
 		try {
-			conn = ConnectionManager.getConnectionManager().getConnection();	
+			conn = ConnectionManager.getConnectionManager().getConnection();
 			//SQL文の定義
 			String sql = "SELECT session_id, jobunit_id, job_id, target_jobunit_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
-			
+
 			stmt.setString(1, session_id);
 			stmt.setString(2, job_id);
-			
+
 			res = stmt.executeQuery();
-			
+
 			while(res.next()) {
 				JobStartJobInfoPK pk= new JobStartJobInfoPK(
 						res.getString("session_id"),
@@ -512,12 +521,12 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 						res.getString("job_id"),
 						res.getString("target_jobunit_id"),
 						res.getString("target_job_id"),
-						res.getInt("target_job_type"), 
+						res.getInt("target_job_type"),
 						res.getInt("target_job_end_value")
 				);
 				ret.add(pk);
 			}
-			
+
 		} catch (SQLException e) {
 			m_log.error("findBySessionIdAndJobId() error : " + session_id + ", " + job_id + " SQLException");
 			throw new EJBException(e.getMessage());
@@ -538,7 +547,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		m_log.debug("findBySessionIdAndJobId() end : " + session_id + ", " + job_id);
 		return ret;
 	}
-	
+
 	/**
 	 * ジョブ待ち条件ジョブ情報をジョブ待ち条件ジョブマスタから作成します。
 	 * 
@@ -551,17 +560,17 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 	 */
 	public void makeSession(String sessionId, String jobunitId, Collection jobs) throws CreateException{
 		m_log.debug("makeSession() start : sessionId=" + sessionId + ", jobunitId=" + jobunitId);
-		
+
 		Connection conn=null;
 		Connection connMaster = null;
 		PreparedStatement stmt=null;
 		PreparedStatement stmtMaster= null;
 		String jobId = null;
-		
+
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			connMaster = ConnectionManager.getConnectionManager().getConnection();
-			
+
 			//SQLL文の定義(INSERT)
 			StringBuilder sql = new StringBuilder();
 			sql.append("INSERT INTO cc_job_start_job_info (");
@@ -573,31 +582,31 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			sql.append("jobunit_id, ");
 			sql.append("target_jobunit_id) ");
 			sql.append("VALUES (?,?,?,?,?,?,?)");
-			
+
 			//SQL文のセット(INSERT)
 			stmt = conn.prepareStatement(sql.toString());
 			stmt.setString(1, sessionId);
 			stmt.setString(6, jobunitId);
 			stmt.setString(7, jobunitId);
-			
+
 			//SQL文の定義(マスタ検索)
 			String sqlMaster = "SELECT * FROM cc_job_start_job_mst WHERE job_id = ? AND jobunit_id = ?";
-			
+
 			//SQL文のセット(マスタ検索)
 			stmtMaster = conn.prepareStatement(sqlMaster);
-			
+
 			Iterator it = jobs.iterator();
 			while(it.hasNext()){
 				//ジョブID取得
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
-				
+
 				//SQL文のセット(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				stmtMaster.setString(2, jobunitId);
 				//SQL実行(マスタ検索)
 				ResultSet resMaster = stmtMaster.executeQuery();
-				
+
 				while(resMaster.next()) {
 					//SQL文のセット(INSERT)
 					stmt.setString(2, resMaster.getString("job_id"));
@@ -619,8 +628,8 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		} catch (SQLException e) {
 			if(e.getSQLState().equals("23505")){
 				m_log.error("makeSession() error : sessionId="
-								+ sessionId + ", jobunitId=" + jobunitId
-								+ ", jobId=" + jobId + " SQLException" + "DuplicateKeyException ");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId + " SQLException" + "DuplicateKeyException ");
 				throw new DuplicateKeyException(e.getMessage());
 			}
 			throw new CreateException(e.getMessage());
@@ -640,12 +649,12 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 				}
 			} catch (SQLException e1) {
 				m_log.error("makeSession() error : sessionId="
-								+ sessionId + ", jobunitId=" + jobunitId
-								+ ", jobId=" + jobId + " SQLException");
+						+ sessionId + ", jobunitId=" + jobunitId
+						+ ", jobId=" + jobId + " SQLException");
 				throw new EJBException(e1.getMessage());
 			}
 		}
 		m_log.debug("makeSession() end : sessionId="
-								+ sessionId + ", jobunitId=" + jobunitId);
+				+ sessionId + ", jobunitId=" + jobunitId);
 	}
 }
