@@ -925,12 +925,22 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	throws FacilityNotFound, HinemosUnknown, JobInfoNotFound, JobMasterNotFound {
 		m_log.debug("runJob() : jobId=" + jobId);
 
+		// 実行可能かのチェック(参照可能なジョブユニットは以下のみ実行可能)
+		Principal pri = m_context.getCallerPrincipal();
+		String loginUser = pri.getName();
+		if(!JobUtil.isReferableJobunit(jobunitId, loginUser)){
+			m_log.warn("runJob() : InvalidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is invisible by loginUser = " + loginUser);
+			throw new HinemosUnknown("runJob() : InvalidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is invisible by loginUser = " + loginUser);
+		}
+		else{
+			m_log.debug("runJob() : ValidUser : This job (jobunitId,jobid) = (" + jobunitId + "," + "jobId" + ") is visible by loginUser = " + loginUser);
+		}
+		
 		if (info == null) {
 			// triggerInfo の実行契機種別が「TRIGGER_MANUAL」の場合、ユーザ名を登録
 			if (triggerInfo.getTrigger_type() == JobTriggerTypeConstant.TYPE_MANUAL) {
-				Principal pri = m_context.getCallerPrincipal();
-				m_log.info("runJob() : pri.getName()=" + pri.getName());
-				triggerInfo.setTrigger_info(pri.getName());
+				m_log.info("runJob() : pri.getName()=" + loginUser);
+				triggerInfo.setTrigger_info(loginUser);
 			}
 		}
 
