@@ -95,6 +95,7 @@ import com.clustercontrol.systemlog.factory.AddMonitorSystemlogString;
 import com.clustercontrol.systemlog.factory.DeleteMonitorSystemlog;
 import com.clustercontrol.systemlog.factory.ModifyMonitorSystemlogString;
 import com.clustercontrol.systemlog.factory.SelectMonitorSystemlog;
+import com.clustercontrol.systemlog.util.SystemlogCache;
 import com.clustercontrol.winservice.factory.AddMonitorWinService;
 import com.clustercontrol.winservice.factory.DeleteMonitorWinService;
 import com.clustercontrol.winservice.factory.ModifyMonitorWinService;
@@ -139,12 +140,6 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 		m_context = ctx;
 	}
 
-	// システムログ監視の性能向上のためのキャッシュ
-	// session beanにキャッシュを作るのは不恰好だが、
-	// デグレリスクを下げるために、ここにキャッシュを作成する。
-	private static ArrayList<MonitorInfo> systemLogMonitorCache = null;
-	private static Object systemLogMonitorLock = new Object();
-
 	/**
 	 * 監視設定情報をマネージャに登録します。<BR>
 	 * 
@@ -297,10 +292,7 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 					if (flag) {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-							synchronized(systemLogMonitorLock) {
-								m_log.info("reset systemLogMonitorCache");
-								systemLogMonitorCache = null;
-							}
+							SystemlogCache.clear();
 						}
 					} else {
 						tm.rollback();
@@ -470,10 +462,7 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 					if (flag) {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-							synchronized(systemLogMonitorLock) {
-								m_log.info("reset systemLogMonitorCache");
-								systemLogMonitorCache = null;
-							}
+							SystemlogCache.clear();
 						}
 					} else {
 						tm.rollback();
@@ -595,10 +584,7 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 					if (flag) {
 						tm.commit();
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-							synchronized(systemLogMonitorLock) {
-								m_log.info("reset systemLogMonitorCache");
-								systemLogMonitorCache = null;
-							}
+							SystemlogCache.clear();
 						}
 					} else {
 						tm.rollback();
@@ -709,156 +695,6 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 		return info;
 	}
 
-	/**
-	 * 監視設定一覧を取得する
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"	 *
-	 * 
-	 * @return
-	 * @throws MonitorNotFound
-	 * @throws HinemosUnknown
-	 */
-	public ArrayList<MonitorInfo> getMonitorList() throws MonitorNotFound, HinemosUnknown{
-
-		ArrayList<MonitorInfo> allList = new ArrayList<MonitorInfo>();
-		ArrayList<MonitorInfo> list = null;
-
-		// Hinemos エージェント監視
-		try{
-			list = getAgentList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// HTTP監視
-		try{
-			list = getHttpList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// ログファイル監視
-		try{
-			list = getLogfileList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// リソース監視
-		try{
-			list = getPerformanceList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// Ping監視
-		try{
-			list = getPingList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// Port監視
-		try{
-			list = getPortList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// Process監視
-		try{
-			list = getProcessList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// SNMPトラップ監視
-		try{
-			list = getTrapList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// SNMP監視
-		try{
-			list = getSnmpList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// SQL監視
-		try{
-			list = getSqlList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// システムログ監視
-		try{
-			list = getSystemlogList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// コマンド監視
-		try{
-			list = getCustomList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		// Windowsサービス監視
-		try{
-			list = getWinServiceList();
-		} catch (Exception e) {
-		}
-		if(list != null){
-			allList.addAll(list);
-			list = null;
-		}
-
-		return allList;
-	}
-
 	/**
 	 * Hinemos Agent監視一覧リストを返します。
 	 * 
@@ -1205,26 +1041,21 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 	 * @throws HinemosUnknown
 	 */
 	public ArrayList<MonitorInfo> getSystemlogList() throws MonitorNotFound, HinemosUnknown{
-		synchronized (systemLogMonitorLock) {
-			if (systemLogMonitorCache != null) {
-				return systemLogMonitorCache;
-			}
-			SelectMonitorSystemlog systemlog = new SelectMonitorSystemlog();
-			try {
-				systemLogMonitorCache = systemlog.getMonitorList(HinemosModuleConstant.MONITOR_SYSTEMLOG);
-			} catch (MonitorNotFound e) {
-				throw e;
-			} catch (Exception e) {
-				m_log.error("getSystemlogList " + e.getMessage(), e);
-				throw new HinemosUnknown(e.getMessage(), e);
-			}
-	
-			// null check
-			if(systemLogMonitorCache == null){
-				systemLogMonitorCache = new ArrayList<MonitorInfo>();
-			}
-			return systemLogMonitorCache;
+		ArrayList<MonitorInfo> list = null;
+		try {
+			list = SystemlogCache.getSystemlogList();
+		} catch (MonitorNotFound e) {
+			throw e;
+		} catch (Exception e) {
+			m_log.error("getSystemlogList " + e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
+		// null check
+		if(list == null){
+			list = new ArrayList<MonitorInfo>();
+		}
+		return list;
+	
 	}
 
 	/**
@@ -1382,41 +1213,40 @@ public abstract class MonitorSettingControllerBean implements SessionBean {
 	}
 
 	/**
-	 * 監視設定一覧の取得
+	 * 監視設定一覧を取得する
 	 * 
 	 * @ejb.interface-method
 	 * 
-	 * @return 監視設定一覧
-	 * @throws HinemosUnknown
+	 * @jboss.method-attributes
+	 *     read-only="true"
+	 * 
+	 * @return
 	 * @throws MonitorNotFound
+	 * @throws HinemosUnknown
 	 */
-	/*
 	public ArrayList<MonitorInfo> getMonitorList() throws MonitorNotFound, HinemosUnknown{
 		m_log.debug("getMonitorList() : start");
-
 		ArrayList<MonitorInfo> list = null;
 		try {
-
 			list = new SelectMonitor().getMonitorList();
-
-		} catch(MonitorNotFound e){
-			m_log.error("getMonitorList() " + e.getMessage(),e);
+		} catch (MonitorNotFound e) {
 			throw e;
 		} catch (Exception e) {
-			m_log.error("getMonitorList() " + e.getMessage(),e);
+			m_log.error("getMonitorList " + e.getMessage(),e);
 			throw new HinemosUnknown(e.getMessage(),e);
 		}
-
 		m_log.debug("getMonitorList() : end");
 		return list;
 	}
-	 */
 
 	/**
 	 * 監視設定一覧の取得
 	 * 
 	 * @ejb.interface-method
 	 * 
+	 * @jboss.method-attributes
+	 *     read-only="true"
+	 *     
 	 * @param condition フィルタ条件
 	 * @return 監視設定一覧
 	 * @throws HinemosUnknown
