@@ -21,7 +21,6 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
-import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 
@@ -57,6 +56,7 @@ import com.clustercontrol.performance.monitor.ejb.entity.MonitorPerfInfoUtil;
 import com.clustercontrol.performance.monitor.util.CallablePerfTask;
 import com.clustercontrol.poller.NotInitializedException;
 import com.clustercontrol.repository.bean.NodeDeviceInfo;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -83,9 +83,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	/** デバイス情報 */
 	private NodeDeviceInfo m_deviceData = null;
 
-	/** 監視ID毎のカウンタ(ファシリティIDについて何回監視を行ったかを保持する) */
-	private static ConcurrentHashMap<String, ConcurrentHashMap<String, Integer>> monitorCountMap = new ConcurrentHashMap<String, ConcurrentHashMap<String,Integer>>();
-
 	/**
 	 * コンストラクタ
 	 * 
@@ -344,7 +341,6 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 				dataManager.getSubPlatformId(),
 				deviceList);
 		boolean fetchFlg = node.fetchSharedTable(m_monitorId);
-		boolean isStart = isMayStart(m_monitorId, facilityId);
 
 		// 2つ分のSharedTableのfetchが失敗した場合
 		if(!fetchFlg){
@@ -360,14 +356,9 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 			perfCheckInfo.setMonitorId(m_perf.getMonitorId());
 			perfCheckInfo.setMonitorTypeId(m_monitor.getMonitorTypeId());
 			schedule.addNodeSchedule(facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
-
-		}
-		// もし2回目に達していなかった場合は通知をしない
-		if(!isStart){
-			m_log.warn("collectList() SharedTable is updated. But it is not the 2nd processing after beginning monitoring. " +
-					"monitorTypeId = " + m_monitorTypeId + ",monitorId = " + m_monitorId  + ", facilityId = " + facilityId);
 			return resultList;
 		}
+		
 		Date d = new Date(node.getLastCollectTime());
 
 		////
@@ -739,64 +730,53 @@ public class RunMonitorPerformance extends RunMonitorNumericValueType {
 	}
 
 
-	/**
-	 * 
-	 * @param monitorId
-	 * @param facilityId
-	 * @return
-	 */
-	private boolean isMayStart(String monitorId, String facilityId){
-		m_log.debug("isMayStart() monitorId = " + monitorId + ", facilityId = " + facilityId);
+	@Override
+	protected boolean setMonitorInfo(String monitorTypeId, String monitorId) throws NamingException, CreateException, FinderException, HinemosUnknown{
+		boolean ret = super.setMonitorInfo(monitorTypeId, monitorId);
+		
+		// 次回が稼働日の場合はスケジュールを再作成する
+		if(!m_isInCalendarTerm && m_isInNextCalendarTerm){
+			try{
+				if(m_repository == null){
+					m_repository = RepositoryControllerUtil.getLocalHome().create();
+				}
+				
+				if(m_perf == null){
+					m_perf = MonitorPerfInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+				}
 
-		ConcurrentHashMap<String, Integer> idCountMap = monitorCountMap.get(monitorId);
-		if(idCountMap == null){
-			idCountMap = new ConcurrentHashMap<String, Integer>();
-			monitorCountMap.put(monitorId, idCountMap);
+				PerfCheckInfo perfCheckInfo = new PerfCheckInfo();
+				perfCheckInfo.setBreakdownFlg(m_perf.getBreakdownFlg());
+				perfCheckInfo.setDeviceDisplayName(m_perf.getDeviceDisplayName());
+				perfCheckInfo.setItemCode(m_perf.getItemCode());
+				perfCheckInfo.setMonitorId(m_perf.getMonitorId());
+				perfCheckInfo.setMonitorTypeId(m_monitor.getMonitorTypeId());
 
-			if(m_log.isDebugEnabled()){
-				m_log.debug("isMayStart() Add MonitorId Map . monitorId = " + monitorId);
+				ModifyPollingSchedule schedule = new ModifyPollingSchedule();
+				if(m_repository.isNode(m_facilityId)){
+					// ノードの場合
+					m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId = " + m_facilityId);
+					schedule.addNodeSchedule(m_facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
+				}
+				else{
+					// スコープの場合
+					ArrayList<String> facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
+					if (facilityList.size() == 0) {
+						m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId is null");
+						return true;
+					}
+					
+					for (String facilityId : facilityList) {
+						m_log.info("pre-schedule : monitorId = " + m_monitorId + ", facilityId = " + facilityId);
+						schedule.addNodeSchedule(facilityId, m_monitorId, m_monitor.getMonitorTypeId(), m_monitor.getRunInterval(), perfCheckInfo);
+					}
+				}
+				
+			} catch (FacilityNotFound e) {
+				m_log.warn("setMonitorInfo() : fail to addSchedule . m_monitorId = " + m_monitorId, e);
 			}
 		}
 
-		Integer counter = idCountMap.get(facilityId);
-		if(counter == null){
-			idCountMap.put(facilityId, 1);
-			if(m_log.isDebugEnabled()){
-				m_log.debug("isMayStart() Add FacilityId Map . monitorId = " + monitorId + ", facilityId = " + facilityId);
-			}
-			return false;
-		}
-
-		if(counter >= 2){
-			if(m_log.isDebugEnabled()){
-				m_log.debug("isMayStart() true. counter = " + counter + ", monitorId = " + monitorId + ", facilityId = " + facilityId);
-			}
-			return true;
-		}else{
-			if(m_log.isDebugEnabled()){
-				m_log.debug("isMayStart() false. counter = " + counter + ", monitorId = " + monitorId + ", facilityId = " + facilityId);
-			}
-			counter = counter + 1;
-			idCountMap.put(facilityId, counter);
-			return false;
-		}
-	}
-
-	/**
-	 * 
-	 * @param monitorId
-	 */
-	public static void clearCounter(String monitorId){
-		m_log.debug("clearCounter() monitorId = " + monitorId);
-		monitorCountMap.remove(monitorId);
-	}
-
-	/**
-	 * 
-	 * @param monitorId
-	 */
-	public static void addCounter(String monitorId){
-		m_log.debug("addCounter() monitorId = " + monitorId);
-		monitorCountMap.put(monitorId, new ConcurrentHashMap<String, Integer>());
+		return ret;
 	}
 }
\ No newline at end of file
