@@ -36,13 +36,15 @@ public class PingProperties {
 	private static final String FPING_COUNT= "1";
 	private static final String FPING_INTERVAL= "1000";
 	private static final String FPING_TIMEOUT="1000";
+	private static final String FPING_BYTES="56";
 	private static final String FPING_PATH="/opt/hinemos/sbin/fping";
 	private static final String FPING6_PATH="/opt/hinemos/sbin/fping6";
-
+	
 	private static final String FPING_ENABLE_KEY = "monitor.ping.fping.enable";
 	private static final String FPING_COUNT_KEY = "monitor.ping.fping.count";
 	private static final String FPING_INTERVAL_KEY="monitor.ping.fping.interval";
 	private static final String FPING_TIMEOUT_KEY="monitor.ping.fping.timeout";
+	private static final String FPING_BYTES_KEY="monitor.ping.fping.bytes";
 	private static final String FPING_PATH_KEY="monitor.ping.fping.path";
 	private static final String FPING6_PATH_KEY="monitor.ping.fping6.path";
 
@@ -56,6 +58,8 @@ public class PingProperties {
 	private static int m_fpingInterval;
 	/** fping利用時のデフォルトの　pingタイムアウト msec*/
 	private static int m_fpingTimeout;
+	/** fping利用時のデフォルトの　ping送信データサイズ byte*/
+	private static int m_fpingBytes;
 
 	/** fping のパス **/
 	private static String m_fpingPath;
@@ -108,6 +112,7 @@ public class PingProperties {
 			String count = properties.getProperty(FPING_COUNT_KEY, FPING_COUNT);
 			String interval = properties.getProperty(FPING_INTERVAL_KEY,FPING_INTERVAL);
 			String timeout = properties.getProperty(FPING_TIMEOUT_KEY,FPING_TIMEOUT);
+			String bytes = properties.getProperty(FPING_BYTES_KEY,FPING_BYTES);
 			m_fpingPath =  properties.getProperty(FPING_PATH_KEY,FPING_PATH);
 			m_fping6Path =  properties.getProperty(FPING6_PATH_KEY,FPING6_PATH);
 
@@ -115,6 +120,7 @@ public class PingProperties {
 			m_fpingCount = new Integer(count).intValue();
 			m_fpingInterval = new Integer(interval).intValue();
 			m_fpingTimeout = new Integer(timeout).intValue();
+			m_fpingBytes = new Integer(bytes).intValue();
 
 		} catch (Exception e) {
 			m_log.error("setValue(): " + e.getMessage());
@@ -137,6 +143,10 @@ public class PingProperties {
 		return m_fpingTimeout;
 	}
 
+	protected static int getFpingBytes() {
+		return m_fpingBytes;
+	}
+	
 	protected static String getFpingPath() {
 
 		return m_fpingPath;
