@@ -57,6 +57,7 @@ import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.notify.util.LogDirectNotifier;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
+import com.clustercontrol.repository.factory.FacilitySelector;
 import com.clustercontrol.systemlog.service.MessageInfo;
 
 /**
@@ -388,7 +389,20 @@ public class AgentEndpoint {
 		HttpAuthenticator.authCheck(wsctx, roleList);
 
 		for (String logFacilityId : getFacilityId(agentInfo)) {
-			new LogDirectNotifier().put("", message, logmsg, monitorInfo, rule, logFacilityId);
+			String facilityId = monitorInfo.getFacilityId();
+			ArrayList<String> facilityList = FacilitySelector.getFacilityIdList(facilityId, 0, false);
+			String str = "";
+			if (m_log.isDebugEnabled()) {
+				for (String s : facilityList) {
+					str += s + ", ";
+				}
+				m_log.debug("facilityId=" + logFacilityId + ", (" + str + ")");
+			}
+			if (facilityList.contains(logFacilityId)) {
+				new LogDirectNotifier().put("", message, logmsg, monitorInfo, rule, logFacilityId);
+			} else {
+				m_log.debug("sendNotify facilityId=" + logFacilityId + ", " + str);
+			}
 		}
 	}
 
